# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='django-thumbor',
    version='0.5.3',
    description=(
        'A django application to resize images using the thumbor service'),
    long_description=open('README.rst').read(),
    author=u'Enrico Batista da Luz',
    author_email='rico.bl@gmail.com',
    url='http://github.com/ricobl/django-thumbor/',
    license=(
        'django-thumbor is licensed under the MIT license. '
        'For more information, please see LICENSE file.'),
    classifiers=[
        'License :: OSI Approved :: MIT License',
    ],
    packages=[
        'django_thumbor',
        'django_thumbor.templatetags',
    ],
    install_requires=(
        'Django>=1.4',
        'libthumbor',
    ),
    tests_require=(
        'django-nose',
        'mock',
    )
)



# -*- coding: utf-8 -*-

from django.conf import settings

# The host serving the thumbor resized images
THUMBOR_SERVER = getattr(settings, 'THUMBOR_SERVER',
                         'http://localhost:8888').rstrip('/')

# The prefix for the host serving the original images
# This must be a resolvable address to allow thumbor to reach the images
THUMBOR_MEDIA_URL = getattr(settings, 'THUMBOR_MEDIA_URL',
                            'http://localhost:8000/media').rstrip('/')

THUMBOR_STATIC_ENABLED = False

THUMBOR_STATIC_URL = getattr(settings, 'THUMBOR_STATIC_URL',
                            'http://localhost:8000/static').rstrip('/')

# The same security key used in the thumbor service to
# match the URL construction
THUMBOR_SECURITY_KEY = getattr(settings, 'THUMBOR_SECURITY_KEY',
                               'MY_SECURE_KEY')

THUMBOR_ARGUMENTS = getattr(settings, 'THUMBOR_ARGUMENTS', {})



# -*- coding: utf-8 -*-

from libthumbor import CryptoURL
from django_thumbor import conf
from django.conf import settings


crypto = CryptoURL(key=conf.THUMBOR_SECURITY_KEY)


def _remove_prefix(url, prefix):
    if url.startswith(prefix):
        return url[len(prefix):]
    return url


def _remove_schema(url):
    return _remove_prefix(url, 'http://')


def _prepend_media_url(url):
    if settings.MEDIA_URL and url.startswith(settings.MEDIA_URL):
        url = _remove_prefix(url, settings.MEDIA_URL)
        url.lstrip('/')
        return '%s/%s' % (conf.THUMBOR_MEDIA_URL, url)
    return url


def _prepend_static_url(url):
    if conf.THUMBOR_STATIC_ENABLED and url.startswith(settings.STATIC_URL):
        url = _remove_prefix(url, settings.STATIC_URL)
        url.lstrip('/')
        return '%s/%s' % (conf.THUMBOR_STATIC_URL, url)
    return url


def generate_url(image_url, **kwargs):
    image_url = _prepend_media_url(image_url)
    image_url = _prepend_static_url(image_url)
    image_url = _remove_schema(image_url)

    kwargs = dict(conf.THUMBOR_ARGUMENTS, **kwargs)
    thumbor_server = kwargs.pop(
        'thumbor_server', conf.THUMBOR_SERVER).rstrip('/')

    encrypted_url = crypto.generate(image_url=image_url, **kwargs).strip('/')

    return '%s/%s' % (thumbor_server, encrypted_url)



# -*- coding: utf-8 -*-

from django import template
from django_thumbor import generate_url

register = template.Library()

try:
    # Python 2
    STRING_TYPES = (basestring,)
except:
    # Python 3
    STRING_TYPES = (str,)

def _parse_filters(filters):
    # Forces an empty filter to the end of the list
    filters += ':'
    # Splits and restores filter closing parenthesis
    filters = [f + ')' for f in filters.split('):')]
    # Ignores the empty filter at the end
    return filters[:-1]

@register.simple_tag
def thumbor_url(image_url, **kwargs):
    filters = kwargs.get('filters')
    if filters and isinstance(filters, STRING_TYPES):
        kwargs['filters'] = _parse_filters(filters)
    return generate_url(image_url=image_url, **kwargs)
